scoretools.PianoStaff
=====================

.. abjad-lineage:: abjad.tools.scoretools.PianoStaff.PianoStaff

.. autoclass:: abjad.tools.scoretools.PianoStaff.PianoStaff

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.scoretools.PianoStaff.PianoStaff.append
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.context_name
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.engraver_consists
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.engraver_removals
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.extend
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.index
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.insert
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.is_nonsemantic
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.is_semantic
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.is_simultaneous
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.name
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.pop
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.remove
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.reverse
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.select_leaves
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.select_notes_and_chords
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.__contains__
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.__copy__
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.__delitem__
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.__eq__
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.__format__
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.__getitem__
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.__illustrate__
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.__len__
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.__mul__
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.__ne__
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.__repr__
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.__rmul__
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.__setitem__

Bases
-----

- :py:class:`scoretools.StaffGroup <abjad.tools.scoretools.StaffGroup.StaffGroup>`

- :py:class:`scoretools.Context <abjad.tools.scoretools.Context.Context>`

- :py:class:`scoretools.Container <abjad.tools.scoretools.Container.Container>`

- :py:class:`scoretools.Component <abjad.tools.scoretools.Component.Component>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.engraver_consists
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.engraver_removals
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.is_semantic
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.context_name
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.is_nonsemantic
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.is_simultaneous
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PianoStaff.PianoStaff.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.append
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.extend
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.index
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.insert
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.pop
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.remove
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.reverse
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.select_leaves
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.select_notes_and_chords
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.__contains__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.__copy__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.__delitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.__eq__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.__format__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.__getitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.__illustrate__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.__len__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.__mul__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.__ne__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.__repr__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.__rmul__
   :noindex:

.. automethod:: abjad.tools.scoretools.PianoStaff.PianoStaff.__setitem__
   :noindex:
